@@ -11,9 +11,9 @@ macro_rules! check_messages {
     ($core_obj:expr) => {
         while let Some(message) = $core_obj.next_message() {
             match message.kind {
-                ::polar_core::messages::MessageKind::Print => ::tracing::debug!("{}", &message.msg),
+                ::polar_core::messages::MessageKind::Print => ::std::println!("{}", &message.msg),
                 ::polar_core::messages::MessageKind::Warning => {
-                    ::tracing::warn!("{}", &message.msg)
+                    ::std::eprintln!("[warning] {}", &message.msg)
                 }
             }
         }
